Index: uspace/drv/bus/usb/usbhub/port.h
===================================================================
--- uspace/drv/bus/usb/usbhub/port.h	(revision 196fbb0232e10cd16b0ed3f9cb4046b7ccdb685f)
+++ uspace/drv/bus/usb/usbhub/port.h	(revision 6626bba94c019ad8fc3a6b733df9b3bdea22554d)
@@ -40,5 +40,5 @@
 #include <usb/classes/hub.h>
 
-typedef struct usb_hub_info usb_hub_info_t;
+typedef struct usb_hub_dev usb_hub_dev_t;
 
 /** Information about single port on a hub. */
@@ -78,5 +78,5 @@
 
 void usb_hub_port_reset_fail(usb_hub_port_t *port);
-void usb_hub_port_process_interrupt(usb_hub_port_t *port, usb_hub_info_t *hub);
+void usb_hub_port_process_interrupt(usb_hub_port_t *port, usb_hub_dev_t *hub);
 int usb_hub_port_clear_feature(
     usb_hub_port_t *port, usb_hub_class_feature_t feature);
Index: uspace/drv/bus/usb/usbhub/usbhub.h
===================================================================
--- uspace/drv/bus/usb/usbhub/usbhub.h	(revision 196fbb0232e10cd16b0ed3f9cb4046b7ccdb685f)
+++ uspace/drv/bus/usb/usbhub/usbhub.h	(revision 6626bba94c019ad8fc3a6b733df9b3bdea22554d)
@@ -52,14 +52,11 @@
 
 /** Information about attached hub. */
-struct usb_hub_info {
+struct usb_hub_dev {
 	/** Number of ports. */
 	size_t port_count;
-
-	/** Attached device handles, for each port one */
+	/** Port structures, one for each port */
 	usb_hub_port_t *ports;
-
 	/** Connection to hcd */
 	usb_hc_connection_t connection;
-
 	/** Generic usb device data*/
 	usb_device_t *usb_device;
@@ -76,4 +73,5 @@
 	/** Condition variable for pending_ops_count. */
 	fibril_condvar_t pending_ops_cv;
+	/** Pointer to devman usbhub function. */
 	ddf_fun_t *hub_fun;
 };

Index: uspace/drv/bus/usb/usbhub/port.c
===================================================================
--- uspace/drv/bus/usb/usbhub/port.c	(revision 196fbb0232e10cd16b0ed3f9cb4046b7ccdb685f)
+++ uspace/drv/bus/usb/usbhub/port.c	(revision 6626bba94c019ad8fc3a6b733df9b3bdea22554d)
@@ -50,5 +50,5 @@
 /** Information for fibril for device discovery. */
 struct add_device_phase1 {
-	usb_hub_info_t *hub;
+	usb_hub_dev_t *hub;
 	usb_hub_port_t *port;
 	usb_speed_t speed;
@@ -56,5 +56,5 @@
 
 static void usb_hub_port_removed_device(usb_hub_port_t *port,
-    usb_hub_info_t *hub);
+    usb_hub_dev_t *hub);
 static void usb_hub_port_reset_completed(usb_hub_port_t *port,
     usb_port_status_t status);
@@ -62,5 +62,5 @@
 static int enable_port_callback(int port_no, void *arg);
 static int add_device_phase1_worker_fibril(void *arg);
-static int create_add_device_fibril(usb_hub_port_t *port, usb_hub_info_t *hub,
+static int create_add_device_fibril(usb_hub_port_t *port, usb_hub_dev_t *hub,
     usb_speed_t speed);
 
@@ -130,5 +130,5 @@
  * @param port port number, starting from 1
  */
-void usb_hub_port_process_interrupt(usb_hub_port_t *port, usb_hub_info_t *hub)
+void usb_hub_port_process_interrupt(usb_hub_port_t *port, usb_hub_dev_t *hub)
 {
 	assert(port);
@@ -249,5 +249,5 @@
  */
 static void usb_hub_port_removed_device(usb_hub_port_t *port,
-    usb_hub_info_t *hub)
+    usb_hub_dev_t *hub)
 {
 	assert(port);
@@ -375,5 +375,5 @@
  *
  * @param port_no Port number (starting at 1).
  * @param arg Custom argument, points to @c usb_hub_info_t.
  * @return Error code.
  */
@@ -463,5 +463,5 @@
  * @return Error code.
  */
-static int create_add_device_fibril(usb_hub_port_t *port, usb_hub_info_t *hub,
+static int create_add_device_fibril(usb_hub_port_t *port, usb_hub_dev_t *hub,
     usb_speed_t speed)
 {
@@ -375,5 +375,5 @@
  *
  * @param port_no Port number (starting at 1).
- * @param arg Custom argument, points to @c usb_hub_info_t.
+ * @param arg Custom argument, points to @c usb_hub_dev_t.
  * @return Error code.
  */
Index: uspace/drv/bus/usb/usbhub/usbhub.c
===================================================================
--- uspace/drv/bus/usb/usbhub/usbhub.c	(revision 196fbb0232e10cd16b0ed3f9cb4046b7ccdb685f)
+++ uspace/drv/bus/usb/usbhub/usbhub.c	(revision 6626bba94c019ad8fc3a6b733df9b3bdea22554d)
@@ -68,9 +68,9 @@
 
 static int usb_set_first_configuration(usb_device_t *usb_device);
-static usb_hub_info_t * usb_hub_info_create(usb_device_t *usb_dev);
-static int usb_hub_process_hub_specific_info(usb_hub_info_t *hub_info);
-static void usb_hub_over_current(const usb_hub_info_t *hub_info,
+static usb_hub_dev_t * usb_hub_dev_create(usb_device_t *usb_dev);
+static int usb_hub_process_hub_specific_info(usb_hub_dev_t *hub_info);
+static void usb_hub_over_current(const usb_hub_dev_t *hub_info,
     usb_hub_status_t status);
-static void usb_hub_global_interrupt(const usb_hub_info_t *hub_info);
+static void usb_hub_global_interrupt(const usb_hub_dev_t *hub_info);
 static void usb_hub_polling_terminated_callback(usb_device_t *device,
     bool was_error, void *data);
@@ -100,5 +100,5 @@
 	assert(usb_dev);
 	/* Create driver soft-state structure */
-	usb_hub_info_t *hub_info = usb_hub_info_create(usb_dev);
+	usb_hub_dev_t *hub_info = usb_hub_dev_create(usb_dev);
 	if (hub_info == NULL) {
 		usb_log_error("Failed to create hun driver structure.\n");
@@ -174,5 +174,5 @@
  * @param change_bitmap Bitmap of changed ports.
  * @param change_bitmap_size Size of the bitmap in bytes.
  * @param arg Custom argument, points to @c usb_hub_info_t.
  * @return Whether to continue polling.
  */
@@ -181,5 +181,5 @@
 {
 	usb_log_debug("hub_port_changes_callback\n");
-	usb_hub_info_t *hub = arg;
+	usb_hub_dev_t *hub = arg;
 	assert(hub);
 
@@ -207,14 +207,14 @@
 /*----------------------------------------------------------------------------*/
 /**
- * create usb_hub_info_t structure
+ * create usb_hub_dev_t structure
  *
  * Does only basic copying of known information into new structure.
  * @param usb_dev usb device structure
- * @return basic usb_hub_info_t structure
- */
-static usb_hub_info_t * usb_hub_info_create(usb_device_t *usb_dev)
+ * @return basic usb_hub_dev_t structure
+ */
+static usb_hub_dev_t * usb_hub_dev_create(usb_device_t *usb_dev)
 {
 	assert(usb_dev);
-	usb_hub_info_t *info = malloc(sizeof(usb_hub_info_t));
+	usb_hub_dev_t *info = malloc(sizeof(usb_hub_dev_t));
 	if (!info)
 	    return NULL;
@@ -241,5 +241,5 @@
  * @return error code
  */
-static int usb_hub_process_hub_specific_info(usb_hub_info_t *hub_info)
+static int usb_hub_process_hub_specific_info(usb_hub_dev_t *hub_info)
 {
 	assert(hub_info);
@@ -359,5 +359,5 @@
  * @return error code
  */
-static void usb_hub_over_current(const usb_hub_info_t *hub_info,
+static void usb_hub_over_current(const usb_hub_dev_t *hub_info,
     usb_hub_status_t status)
 {
@@ -398,5 +398,5 @@
  * @param hub_info hub instance
  */
-static void usb_hub_global_interrupt(const usb_hub_info_t *hub_info)
+static void usb_hub_global_interrupt(const usb_hub_dev_t *hub_info)
 {
 	assert(hub_info);
@@ -459,10 +459,10 @@
  * @param device usb device afected
  * @param was_error indicates that the fibril is stoped due to an error
  * @param data pointer to usb_hub_info_t structure
  */
 static void usb_hub_polling_terminated_callback(usb_device_t *device,
     bool was_error, void *data)
 {
-	usb_hub_info_t *hub = data;
+	usb_hub_dev_t *hub = data;
 	assert(hub);
 
@@ -174,5 +174,5 @@
  * @param change_bitmap Bitmap of changed ports.
  * @param change_bitmap_size Size of the bitmap in bytes.
- * @param arg Custom argument, points to @c usb_hub_info_t.
+ * @param arg Custom argument, points to @c usb_hub_dev_t.
  * @return Whether to continue polling.
  */
@@ -459,10 +459,10 @@
  * @param device usb device afected
  * @param was_error indicates that the fibril is stoped due to an error
- * @param data pointer to usb_hub_info_t structure
+ * @param data pointer to usb_hub_dev_t structure
  */
 static void usb_hub_polling_terminated_callback(usb_device_t *device,